==> nextcloud-22.2.3.tgz: nextcloud/apps/comments/l10n/zh_HK.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "留言",
    "You commented" : "您已留言",
    "%1$s commented" : "%1$s 個留言",
    "{author} commented" : "{author} 已留言",
    "You commented on %1$s" : "你對 %1$s 留了言",
    "You commented on {file}" : "你對 {file} 留了言",
    "%1$s commented on %2$s" : "%1$s 對 %2$s 留了言",
    "{author} commented on {file}" : "{author} 對 {file} 留了言",
    "<strong>Comments</strong> for files" : "檔案的<strong>留言</strong>",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "一個已被刪除的用戶在 “{file}” 的留言中提到你",
    "{user} mentioned you in a comment on “{file}”" : "{user} 在 “{file}” 的留言中提到你",
    "Files app plugin to add comments to files" : "檔案插件程式插件，用於為檔案增加註釋",
    "Edit comment" : "編輯留言",
    "Delete comment" : "刪除留言",
    "Cancel edit" : "取消編輯",
    "Post comment" : "張貼留言",
    "No comments yet, start the conversation!" : "尚無留言，開始討論吧！",
    "No more messages" : "沒有更多訊息",
    "Retry" : "重試",
    "Unable to load the comments list" : "無法載入留言清單",
    "_%n unread comment_::_%n unread comments_" : ["%n 個未讀留言"],
    "_1 new comment_::_{unread} new comments_" : ["{unread} 個新留言"],
    "Comment" : "留言",
    "An error occurred while trying to edit the comment" : "嘗試編輯此留言時錯誤",
    "Comment deleted" : "意見刪除",
    "An error occurred while trying to delete the comment" : "嘗試刪除此留言時錯誤",
    "An error occurred while trying to create the comment" : "嘗試建立此留言時錯誤",
    "New comment …" : "新增留言",
    "Post" : "送出",
    "Cancel" : "取消",
    "[Deleted user]" : "[已刪除的用戶]",
    "More comments …" : "更多留言…",
    "Save" : "儲存",
    "Allowed characters {count} of {max}" : "已輸入 {count} / {max}",
    "Error occurred while retrieving comment with ID {id}" : "在擷取留言（ID {id}）時發生錯誤",
    "Error occurred while updating comment with id {id}" : "編輯留言（ID {id}）時發生錯誤",
    "Error occurred while posting comment" : "張貼留言時發生錯誤"
},
"nplurals=1; plural=0;");

==> nextcloud-22.2.4.tgz: nextcloud/apps/comments/l10n/zh_HK.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "留言",
    "You commented" : "您已留言",
    "%1$s commented" : "%1$s 個留言",
    "{author} commented" : "{author} 已留言",
    "You commented on %1$s" : "你對 %1$s 留了言",
    "You commented on {file}" : "你對 {file} 留了言",
    "%1$s commented on %2$s" : "%1$s 對 %2$s 留了言",
    "{author} commented on {file}" : "{author} 對 {file} 留了言",
    "<strong>Comments</strong> for files" : "檔案的<strong>留言</strong>",
    "You were mentioned on \"{file}\", in a comment by a user that has since been deleted" : "一個已被刪除的用戶在 “{file}” 的留言中提到你",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} 在 “{file}” 的留言中提到你",
    "Files app plugin to add comments to files" : "檔案插件程式插件，用於為檔案增加註釋",
    "Edit comment" : "編輯留言",
    "Delete comment" : "刪除留言",
    "Cancel edit" : "取消編輯",
    "Post comment" : "張貼留言",
    "No comments yet, start the conversation!" : "尚無留言，開始討論吧！",
    "No more messages" : "沒有更多訊息",
    "Retry" : "重試",
    "Unable to load the comments list" : "無法載入留言清單",
    "_%n unread comment_::_%n unread comments_" : ["%n 個未讀留言"],
    "_1 new comment_::_{unread} new comments_" : ["{unread} 個新留言"],
    "Comment" : "留言",
    "An error occurred while trying to edit the comment" : "嘗試編輯此留言時錯誤",
    "Comment deleted" : "意見刪除",
    "An error occurred while trying to delete the comment" : "嘗試刪除此留言時錯誤",
    "An error occurred while trying to create the comment" : "嘗試建立此留言時錯誤",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "一個已被刪除的用戶在 “{file}” 的留言中提到你",
    "{user} mentioned you in a comment on “{file}”" : "{user} 在 “{file}” 的留言中提到你",
    "New comment …" : "新增留言",
    "Post" : "送出",
    "Cancel" : "取消",
    "[Deleted user]" : "[已刪除的用戶]",
    "More comments …" : "更多留言…",
    "Save" : "儲存",
    "Allowed characters {count} of {max}" : "已輸入 {count} / {max}",
    "Error occurred while retrieving comment with ID {id}" : "在擷取留言（ID {id}）時發生錯誤",
    "Error occurred while updating comment with id {id}" : "編輯留言（ID {id}）時發生錯誤",
    "Error occurred while posting comment" : "張貼留言時發生錯誤"
},
"nplurals=1; plural=0;");
